@@ -1,12 +1,15 @@
 from django import template
 from django.template import Node, Token, TemplateSyntaxError
-from django.template import resolve_variable, defaulttags
+from django.template import resolve_variable
 from django.template.defaultfilters import stringfilter
+from django.templatetags import future
+
 from localeurl import utils
 
 register = template.Library()
 
 
+
 def chlocale(url, locale):
     """
     Changes the URL's locale prefix if the path is not locale-independent.
@@ -16,20 +19,24 @@ def chlocale(url, locale):
     _, path = utils.strip_path(path)
     return utils.locale_url(path, locale)
 
+
 chlocale = stringfilter(chlocale)
 register.filter('chlocale', chlocale)
 
 
+
 def rmlocale(url):
     """Removes the locale prefix from the URL."""
     script_prefix, path = utils.strip_script_prefix(url)
     _, path = utils.strip_path(path)
     return ''.join([script_prefix, path])
 
+
 rmlocale = stringfilter(rmlocale)
 register.filter('rmlocale', rmlocale)
 
 
+
 def locale_url(parser, token):
     """
     Renders the url for the view with another locale prefix. The syntax is
@@ -45,9 +52,10 @@ def locale_url(parser, token):
         raise TemplateSyntaxError("'%s' takes at least two arguments:"
                 " the locale and a view" % bits[0])
     urltoken = Token(token.token_type, bits[0] + ' ' + ' '.join(bits[2:]))
-    urlnode = defaulttags.url(parser, urltoken)
+    urlnode = future.url(parser, urltoken)
     return LocaleURLNode(bits[1], urlnode)
 
+
 class LocaleURLNode(Node):
     def __init__(self, locale, urlnode):
         self.locale = locale
@@ -66,4 +74,5 @@ class LocaleURLNode(Node):
         else:
             return chlocale(path, locale)
 
+
 register.tag('locale_url', locale_url)
