@@ -1,14 +1,18 @@
 from django.conf import settings
 from django.core import urlresolvers
-from django.core import urlresolvers
 from localeurl import settings as localeurl_settings
 
 def is_locale_independent(path):
     """
     Returns whether the path is locale-independent.
     """
-    if localeurl_settings.LOCALE_INDEPENDENT_MEDIA_URL and settings.MEDIA_URL \
-            and path.startswith(settings.MEDIA_URL):
+    if (localeurl_settings.LOCALE_INDEPENDENT_MEDIA_URL and
+        settings.MEDIA_URL and
+        path.startswith(settings.MEDIA_URL)):
+        return True
+    if (localeurl_settings.LOCALE_INDEPENDENT_STATIC_URL and
+        getattr(settings, "STATIC_URL", None) and
+        path.startswith(settings.STATIC_URL)):
         return True
     for regex in localeurl_settings.LOCALE_INDEPENDENT_PATHS:
         if regex.search(path):
@@ -31,6 +35,7 @@ def supported_language(locale):
     """
     Returns the supported language (from settings.LANGUAGES) for the locale.
     """
+    locale = locale.lower()
     if locale in localeurl_settings.SUPPORTED_LOCALES:
         return locale
     elif locale[:2] in localeurl_settings.SUPPORTED_LOCALES:
@@ -65,7 +70,7 @@ def locale_url(path, locale=''):
     the locale is empty settings.LANGUAGE_CODE is used.
     """
     path = locale_path(path, locale)
-    return ''.join([urlresolvers.get_script_prefix(), path[1:]])
+    return add_script_prefix(path)
 
 def strip_script_prefix(url):
     """
@@ -76,3 +81,10 @@ def strip_script_prefix(url):
             "URL must start with SCRIPT_PREFIX: %s" % url
     pos = len(urlresolvers.get_script_prefix()) - 1
     return url[:pos], url[pos:]
+
+def add_script_prefix(path):
+    """
+    Prepends the SCRIPT_PREFIX to a path.
+    """
+
+    return ''.join([urlresolvers.get_script_prefix(), path[1:]])
