@@ -2,6 +2,7 @@ from urlparse import urlsplit
 from django import http
 from django.utils.translation import check_for_language
 from localeurl import utils
+from localeurl import settings as localeurl_settings
 
 def change_locale(request):
     """
@@ -11,14 +12,17 @@ def change_locale(request):
     """
     next = request.REQUEST.get('next', None)
     if not next:
-        next = request.META.get('HTTP_REFERER', None)
+        referrer = request.META.get('HTTP_REFERER', None)
+        if referrer:
+            next = urlsplit(referrer)[2]
     if not next:
         next = '/'
-    next = urlsplit(next).path
     _, path = utils.strip_path(next)
     if request.method == 'POST':
         locale = request.POST.get('locale', None)
         if locale and check_for_language(locale):
+            if localeurl_settings.USE_SESSION:
+                request.session['django_language'] = locale
             path = utils.locale_path(path, locale)
 
     response = http.HttpResponseRedirect(path)
